@@ -8,8 +8,6 @@ Note: If code contains something like a + b, or a * b, where
 a and b are integer literals (e.g. 2 + 4), the operations are
 done prior to the creation of a code object and thus are
 not captured by this transformation.
-
-Requires Python version 3.6 or 3.7.
 """
 import dis
 import sys
@@ -18,8 +16,6 @@ from types import CodeType
 
 from ideas import import_hook
 
-assert sys.version_info.minor in (6, 7)
-
 ADD = dis.opmap["BINARY_ADD"]
 MUL = dis.opmap["BINARY_MULTIPLY"]
 
@@ -38,7 +34,7 @@ def swap_add_mul(bytecode):
 
 
 def create_new_co(code_object):
-    """Recursivelly creates new code objects from old ones, swapping
+    """Recursively creates new code objects from old ones, swapping
     BINARY_ADD and BINARY_MULTIPLY.
     """
     new_code = swap_add_mul(code_object.co_code)
@@ -48,23 +44,44 @@ def create_new_co(code_object):
             new_const.append(create_new_co(c))
         else:
             new_const.append(c)
-    new_code_object = CodeType(
-        code_object.co_argcount,
-        code_object.co_kwonlyargcount,
-        code_object.co_nlocals,
-        code_object.co_stacksize,
-        code_object.co_flags,
-        new_code,
-        tuple(new_const),
-        code_object.co_names,
-        code_object.co_varnames,
-        code_object.co_filename,
-        code_object.co_name,
-        code_object.co_firstlineno,
-        code_object.co_lnotab,
-        code_object.co_freevars,
-        code_object.co_cellvars,
-    )
+
+    if sys.version_info.minor in (6, 7):
+        new_code_object = CodeType(
+            code_object.co_argcount,
+            code_object.co_kwonlyargcount,
+            code_object.co_nlocals,
+            code_object.co_stacksize,
+            code_object.co_flags,
+            new_code,
+            tuple(new_const),
+            code_object.co_names,
+            code_object.co_varnames,
+            code_object.co_filename,
+            code_object.co_name,
+            code_object.co_firstlineno,
+            code_object.co_lnotab,
+            code_object.co_freevars,
+            code_object.co_cellvars,
+        )
+    else:
+        new_code_object = CodeType(
+            code_object.co_argcount,
+            code_object.co_posonlyargcount,  # new
+            code_object.co_kwonlyargcount,
+            code_object.co_nlocals,
+            code_object.co_stacksize,
+            code_object.co_flags,
+            new_code,
+            tuple(new_const),
+            code_object.co_names,
+            code_object.co_varnames,
+            code_object.co_filename,
+            code_object.co_name,
+            code_object.co_firstlineno,
+            code_object.co_lnotab,
+            code_object.co_freevars,
+            code_object.co_cellvars,
+        )
     return new_code_object
 
 
