@@ -272,7 +272,9 @@ def create_hook(
     if transform_source is not None:
         try:
             ip = get_ipython()  # noqa
-            ipython_source_transformer = make_ipython_source_transformer(transform_source)
+            ipython_source_transformer = make_ipython_source_transformer(
+                transform_source
+            )
             ip.input_transformers_post.append(ipython_source_transformer)
         except NameError:
             pass
@@ -286,12 +288,14 @@ def create_hook(
 
     return hook
 
+
 def make_ipython_source_transformer(transform_source):
     def ipython_source_transformer(lines):
         source = "".join(lines)
         source = transform_source(source)
         lines = source.splitlines(keepends=True)
         return lines
+
     return ipython_source_transformer
 
 
