@@ -1,7 +1,5 @@
 from ideas.import_hook import remove_hook
 from ideas.examples import decimal_math
-import sys
-import pytest
 
 
 def test_import_with_hook():
@@ -13,8 +11,6 @@ def test_import_with_hook():
     remove_hook(hook)
 
 
-@pytest.mark.skipif(sys.version_info.minor not in (6, 7, 8),
-                    reason="requires python 3.6, 3.7 or 3.8")
 def test_import_with_encoding():
     decimal_math.register()
     try:
