@@ -1,6 +1,4 @@
 from ideas.examples import nobreak
-# from ideas.import_hook import remove_hook
-
 
 def test_for():
     source_for = """
@@ -10,7 +8,7 @@ def test_for():
         pass"""
 
     source = source_for % "nobreak"
-    result = nobreak.nobreak_as_a_keyword(source)
+    result = nobreak.transform_source(source)
     expected = source_for % "else"
 
     assert result == expected, "nobreak with for"
@@ -24,12 +22,12 @@ def test_while():
         pass"""
 
     source = source_while % "nobreak"
-    result = nobreak.nobreak_as_a_keyword(source)
+    result = nobreak.transform_source(source)
     expected = source_while % "else"
 
     assert result == expected, "nobreak with while"
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     test_for()
     print("test_nobreak was run successfully.")
